==> open-xchange-usm_7.2.1.orig.tar.bz2: open-xchange-usm-7.2.1/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/impl/DataObjectStorageSQLStatements.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.session.impl;

public class DataObjectStorageSQLStatements {

	public static final String FULL_INSERT = "INSERT INTO USMDataStorage (cid, usmSessionId, objectId, syncKey, element) VALUES (?, ?, ?, ?, ?)";

	public static final String DELETE = "DELETE FROM USMDataStorage WHERE ";

	public static final String SELECT_CACHED_DATA = "SELECT syncKey, element FROM USMDataStorage WHERE ";

	public static final String SELECT_CACHED_DATA_ORDER_BY = " ORDER BY syncKey";

	public static final String UNIQUE_SESSION_IDENTIFIER = "cid = ? AND usmSessionId = ?";

	public static final String UNIQUE_OBJECT_IDENTIFIER = UNIQUE_SESSION_IDENTIFIER + " AND objectId = ?";

	public static final String SINGLE_ELEMENT_IDENTIFIER = UNIQUE_OBJECT_IDENTIFIER + " AND syncKey = ?";

	public static final String CACHE_DELETE_CONDITION_SIMPLE = " AND (syncKey = ? OR syncKey < ?)";

	public static final String CACHE_DELETE_CONDITION_COMPLEX = " AND (syncKey = ? OR (syncKey < ? AND syncKey != ? ))";

	public static final String SELECT_OBJECT_IDS = "SELECT DISTINCT objectId FROM USMDataStorage WHERE " + UNIQUE_SESSION_IDENTIFIER;
}

==> open-xchange-usm_7.4.1.orig.tar.bz2: open-xchange-usm-7.4.1/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/impl/DataObjectStorageSQLStatements.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.session.impl;

public class DataObjectStorageSQLStatements {

	public static final String FULL_INSERT = "INSERT INTO USMDataStorage (cid, usmSessionId, objectId, syncKey, element) VALUES (?, ?, ?, ?, ?)";
	
	public static final String FULL_INSERT_IGNORE = "INSERT IGNORE INTO USMDataStorage (cid, usmSessionId, objectId, syncKey, element) VALUES (?, ?, ?, ?, ?)";

	public static final String DELETE = "DELETE FROM USMDataStorage WHERE ";

	public static final String SELECT_CACHED_DATA = "SELECT syncKey, element FROM USMDataStorage WHERE ";

	public static final String SELECT_CACHED_DATA_ORDER_BY = " ORDER BY syncKey";

	public static final String UNIQUE_SESSION_IDENTIFIER = "cid = ? AND usmSessionId = ?";

	public static final String UNIQUE_OBJECT_IDENTIFIER = UNIQUE_SESSION_IDENTIFIER + " AND objectId = ?";

	public static final String SINGLE_ELEMENT_IDENTIFIER = UNIQUE_OBJECT_IDENTIFIER + " AND syncKey = ?";

	public static final String CACHE_DELETE_CONDITION_SIMPLE = " AND syncKey < ?";

	public static final String CACHE_DELETE_CONDITION_EXTENSION = " AND syncKey != ?";

	public static final String SELECT_OBJECT_IDS = "SELECT DISTINCT objectId FROM USMDataStorage WHERE " + UNIQUE_SESSION_IDENTIFIER;
	
	public static final String SIMPLE_SYNCSTATE_DELETE = DELETE + UNIQUE_OBJECT_IDENTIFIER + CACHE_DELETE_CONDITION_SIMPLE;
	
    public static final String COMPLEX_SYNCSTATE_DELETE = SIMPLE_SYNCSTATE_DELETE + CACHE_DELETE_CONDITION_EXTENSION;
}
